# Waldiez Studio

![CI Build](https://github.com/waldiez/studio/actions/workflows/main.yaml/badge.svg) [![Coverage Status](https://coveralls.io/repos/github/waldiez/studio/badge.svg)](https://coveralls.io/github/waldiez/studio)

![Screenshot](https://github.com/waldiez/studio/blob/main/public/files/screenshots/1.webp)

## Status

- [x] **Handle workspaces** - Create, rename, delete, flows and folders, upload and download files.
- [x] **Render waldiez flows** - Render waldiez flows in the browser.
- [x] **Covert waldiez flows** - Convert waldiez flows to python and/or jupyter notebook.
- [x] **Run waldiez flows** - Run waldiez flows using websockets for real-time updates and user interaction.

## License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/waldiez/studio/blob/main/LICENSE) file for details.
